{% extends 'dinette/base.html' %}

{% block title %}
{{ topic.subject }} - {{ block.super }}
{% endblock %}



{% block content %}

{% for topic in topic_list %}
<a href="{% url dinette_topic_detail topic.category.slug topic.slug %}">{{topic}}<a>
{% endfor %}

{% endblock %}
