/*************************************************************
IE7 - FIXES
**************************************************************/

/* Float Clearing and Has Layout Fixes
-------------------------------------------------------------*/

.brd-page,
.brd .main,
#brd-index .main-subhead,
#brd-index .forum-item,
.brd .gen-content,
.brd .main-content,
.brd .ct-box,
.brd .ct-box *,
.brd .frm-group,
.brd .mf-set,
.brd .sf-set,
.brd .mf-box,
.brd .sf-box,
.brd .mf-item,
.brd .txt-set,
.brd .txt-box,
.brd .frm-group label,
.brd fieldset,
.brd span.fld-input,
.brd .main-subhead .hn,
.brd .post,
.brd .postbody,
.brd .post-entry,
.brd .postfoot .post-options,
#brd-stats ul {
	max-height: 100%;
	zoom: 1;
	}

/* Forms
-------------------------------------------------------------*/

#brd-wrap fieldset {
	padding-top: 1px;
	position: relative;
	}

.brd fieldset legend {
	margin-left: -7px;
	}

#brd-wrap .entry-content .codebox pre {min-height: 3em}

#brd-admin-censoring #info-censored-intro, #brd-admin-ranks #info-ranks-intro {
	margin-bottom: 3em;
	}

.main-forum .main-item .item-starter {
	margin-left: 1ex;
	}

#brd-admin-settings-setup #fld19, #brd-post textarea#fld1, #brd-post textarea#fld2, #brd-viewtopic textarea#fld1, #brd-postedit #fld2 {
	margin-top: -19px;
}