
{% load thumbnail %} 
 
<!-- div.post/even/replypost begins-->
<a name="{{ reply.reply_number }}"></a>
<div class="post even replypost">
  <!-- div p120560 begins-->
  <div id="p120560" class="posthead">
    <h3 class="hn post-ident">
	  <span class="post-num">   </span>
	  <span class="post-byline">
	    <span>Reply by </span>
		<a title="" href="#"></a>
	  </span>
      <span class="post-link">
	    <a class="permalink" rel="bookmark" title="Permanent link to this post" href="{{ reply.get_url_with_fragment }}">{{ reply.created_on|date:"jS F Y H:i A" }}</a>
	  </span> &nbsp; &nbsp; &nbsp;
	</h3>
  </div>
  <!-- div p120560 ends-->
  
  <!-- div.postbody begins-->
  <div class="postbody">
	<!-- div.post-author begins-->
    <div class="post-author">
	  <!-- ul.author-indent begins-->
	  <ul class="author-ident">
	    <li>
		  <table class="authortable">
		  <tr><td>
		    {% if reply.posted_by.get_profile.photo  %}
		      <img src="{% thumbnail reply.posted_by.get_profile.photo 80x80 %}" />
		    {% else %}                                                        
		      <img src="http://www.gravatar.com/avatar/{{reply.posted_by.get_profile.getMD5}}.jpg" alt="{{reply.posted_by.username}}'s Photo" />
		    {% endif %} 
		  </td></tr>
		  <tr><td>
		    <a href="{{ reply.posted_by.get_profile.get_absolute_url }}">{{reply.posted_by.username}}</a>
		  </td></tr>
		  </table>
		</li>
		<li class="usertitle"><span>{{ reply.posted_by.get_profile.userrank }}  </span></li>
		<li class="userstatus">
		  <span>
		  {% if reply.posted_by.get_profile.is_online %}
			Online
		  {% else %}
			Offline
		  {% endif %}
		  </span>
		</li>
	  </ul>
	  <!-- ul.author-indent ends-->
	  
	  <!-- ul.author-info begins-->
	  <ul class="author-info">
	    <li>
		  <span>Registered: 
		    <strong> {{ reply.posted_by.date_joined|date:"jS F Y H:i A" }}</strong>
		  </span>
		</li>
		<li>
		  <span>Posts: 
		    <strong> {{ reply.posted_by.get_profile.get_total_posts  }}</strong>
		  </span>
		</li>
	  </ul>
	  <!-- ul.author-info ends-->
	</div>
	<!-- div.post-author ends-->

	<div class="post-entry">
	  <h4 id="pc120560" class="entry-title hn">Re: {{reply.topic.subject}}</h4>
	  <div class="entry-content">
  	    <p>  {{ reply.message|safe }}</p>
	    {% with reply as rtopic %}    
	      {% include 'dinette/attachement_frag.html' %}     
	    {% endwith %}
	  </div>
	</div>
	
  </div>
  <!-- div.postbody ends-->

</div>        
<!-- div.post/even/replypost ends-->
