{% extends "dinette/base.html" %}
	


{% block content %}
	
	<div id="brd-wrap" class="brd">
	  	<div id="brd-index" class="brd-page basic-page">
		{% include 'dinette/header_frag.html' %}
		{% include 'dinette/announce_frag.html' %}
		<p></p>
		</div>
		<h2 class="hn"><span><span class="item-info">{{ page_message }}</span></span></h2>
	</div>	

	<div class="brd">
		<form>
				{{ form.as_p }}
			<input type="submit" name="submit" value="search" />
		</form>
	</div>
	
	<div class="brd">
		<ul>
			{% for result in page.object_list %}
				<li>
					<strong><a href="{{ result.object.get_absolute_url }}">{{ result.object }}</a></strong>
					{% if result.object.search_snippet %}
					<p>
						{{ result.object.search_snippet }}
					</p>
					{% endif %}
				
				</li>
			{% empty %}
				<li><p>We do not have any results for this query.</p></li> 
			{% endfor %}
		</ul>
	</div>
	

{% endblock content %}