/*************************************************************
IE6 - FIXES
**************************************************************/

/* Float Clearing and Has Layout Fixes
-------------------------------------------------------------*/

.brd-page,
.brd .main,
#brd-index .main-subhead,
.brd .main-content .main-item,
.brd .main-content .main-item ul,
.brd .gen-content,
.brd .main-content,
.brd .ct-box,
.brd .ct-box *,
.brd .frm-group,
.brd .mf-set,
.brd .sf-set,
.brd .mf-box,
.brd .sf-box,
.brd .mf-item,
.brd .txt-set,
.brd .txt-box,
.brd .frm-form label,
.brd fieldset,
.brd span.fld-input,
.brd .main-subhead .hn,
.brd .post,
.brd .postbody,
.brd .post-entry,
.brd .postfoot .post-options {
	zoom: 1;
	}

/* Forms
-------------------------------------------------------------*/

#brd-wrap fieldset {
	padding-top: 1px;
	position: relative;
	}

.brd fieldset legend {
	margin-left: -7px;
	}

#brd-wrap .checklist {
	height: 9em;
	width: 30em;
	overflow: auto;
	}

.brd .sf-set .checkbox label span {
	padding-right: 0em;
	padding-left: 5em;
	}

#brd-admin-censoring #info-censored-intro, #brd-admin-ranks #info-ranks-intro { margin-bottom: 3em; }

/* Adding space between topic subject and its' info */
#brd-viewforum .item-nav, .main-forum .item-subject .item-starter { margin-left: 1ex; }

.important strong { margin-right: 1ex; }

#brd-stats .st-users { margin-bottom: -1ex; }

/* Fixes for the forms in post.php and edit.php. */
.brd .txt-box label span { position: absolute; }
/* Try this fixes if something's wrong */
/*
#brd-post #post-form .sf-set .fld-input { padding-top: 1.7em; }
#brd-postedit	#post-form .set2 .txt-box .fld-input,
#brd-post		#post-form .txt-box .fld-input { padding-top: 1.3em; }
#brd-postedit	#post-form .mf-item #fld2,
#brd-post		#post-form .mf-item #fld2 { top: 1.25em; left: -0.25em; position: relative; }
*/

/* Fix for index.php: no backgroud for the first main-head. */
.brd #brd-index .main-head { position: relative; }

.brd .main-content .main-item .hn .posted-mark {
 	left: 0.2em;
	}
