import os
from django.conf import global_settings


#topic page size
TOPIC_PAGE_SIZE = 3


#REPLY PAGE SIZE
REPLY_PAGE_SIZE = 3


#Flood Time
FLOOD_TIME = 5




AUTH_PROFILE_MODULE = 'dinette.DinetteUserProfile'

#Append out new template processors to already existing processors
templist = list(global_settings.TEMPLATE_CONTEXT_PROCESSORS)
templist.append("dinette.context_processors.get_announcement")
templist.append("dinette.context_processors.get_site_config")
TEMPLATE_CONTEXT_PROCESSORS = tuple(templist)