from django.contrib import admin

from dinette import models

admin.site.register(models.SuperCategory)
admin.site.register(models.Category)
admin.site.register(models.Ftopics)
admin.site.register(models.Reply)
admin.site.register(models.DinetteUserProfile)
admin.site.register(models.SiteConfig)
admin.site.register(models.NavLink)



