    {% load thumbnail %}    
    
    {%ifequal  rtopic.attachment_type  "text"%}
    <p>
    ----- <br/>
    <strong> File Attachment : </strong>  <br/>
    <a href="{{MEDIA_URL}}/{{rtopic.file}}" > {{rtopic.filename}}  </a>
    &nbsp; <a href=""> Download </a>
    </p>
    {% endifequal %}
    
    
     {%ifequal  rtopic.attachment_type  "image"%}
    <p>
    ----- <br/>
    <strong> Image Attachment : </strong>  <br/>
    {{rtopic.filename}}<br/><br/>
    <a href="{{MEDIA_URL}}/{{rtopic.file}}">
        
        <img src="{% thumbnail rtopic.file 200x200 %}" />
        
    </a>   
    &nbsp; <a href=""> Download </a>
    </p>
    {% endifequal %}
                                                