<div id="topic{{ topic.pk }}" class="main-item odd main-first-item normal">
  {% if topic.is_closed %}
	<span class="icon closed"><!-- --></span>
  {% endif %}
  
  {% if topic.is_sticky %}
	<span class="icon sticky"><!-- --></span>
  {% endif %}
  
  {% if topic.is_normal %}
	<span class="icon normal"><!-- --></span>
  {% endif %}
  
  <div class="item-subject">
	<h3 class="hn"><span class="item-num">1</span>
	  {% if topic.is_closed %}
		<strong>(Closed)</strong>
	  {% endif %}
	  
	  {% if topic.is_sticky %}
		<strong>(Sticky)</strong>
	  {% endif %}		
	  <a href="{% url dinette_topic_detail topic.category.slug topic.slug %}">{{topic.subject}} </a>   
	</h3>
	&nbsp; <span class="item-starter">by <cite>{{topic.posted_by.username}}</cite></span>
  </div>
  
  <ul class="item-info">
	<li class="info-replies">
	  <strong>{{ topic.reply_set.count }}</strong> 
	  <span class="label">replies</span>
	</li>
	<li class="info-views">
	  <strong>{{ topic.viewcount }}</strong> 
	  <span class="label">views</span>
	</li>
	<li class="info-lastpost">
	  <span class="label">Last post</span>
	  <strong><a href="{{ topic.get_absolute_url }}">{{ topic.lastPostDatetime|date:"jS F Y H:i A" }}</a></strong>
	  <cite>by {{topic.lastPostedUser}}</cite>
	</li>
  </ul>

</div>

